@@ -5,7 +5,8 @@
     Blog metadata extension. The extension extracts and computes metadata 
     associated with blog posts/pages and stores it in the environment.
 
-    :copyright: Copyright 2011 by Vlad Riscutia.
+    :copyright: Copyright 2011-2012 by Vlad Riscutia and contributors (see
+    CONTRIBUTORS file)
     :license: FreeBSD, see LICENSE file
 '''
 import re
@@ -115,7 +116,7 @@ def process_metadata(app, env):
                 else:
                     env.blog_pages.append(doc)
      
-    env.blog_page_list = [("index", "Home")] + [(page, env.titles[page].astext()) for page in env.blog_pages]
+    env.blog_page_list = [("index", _("Home"))] + [(page, env.titles[page].astext()) for page in env.blog_pages]
 
 
 
@@ -128,6 +129,14 @@ def add_metadata(app, pagename, context):
     # blog tagline and pages
     context["tagline"] = app.config.tagline
     context["pages"] = env.blog_page_list
+    
+    # set translation context variables
+    context["text_recent_posts"] = _("Recent Posts")
+    context["text_posted_by"] = _("Posted by")
+    context["text_blog_archive"] = _("Blog Archive")
+    context["text_filed_under"] = _("Filed under")
+    context["text_tags"] = _("Tags")
+    context["timestamp_format"] = _('%B %d, %Y')    
 
     # recent posts
     context["recent"] = [(post, env.titles[post].astext()) for post 
